//************************************************************************* 
//  Calorimeter.cxx - 8/1/2012
// 
//  by tadejd
// 
//  This class is used to create planar view of calorimeter.
//
//
//*************************************************************************  

#include "TMath.h"
#include <cstring>
#include <cstdio>
#include <iostream>
#include <sstream>

#include "Calorimeter.h"

#define DEBUG_LEVEL 0

using namespace std;


Calorimeter::Calorimeter(char *ime, int n, double blengthL, double blengthR, double bhight, double offset, CStransform *trans)
{
//n->number of blocks in layer; blengthL/blengthR->length of left/right block; layer y-offset  

  cst = trans;
  N = n;
  layer_length = blengthL+blengthR;
  layer_hight = n*bhight/2.0;

  // now we make proper transformation to get to the left upper corner.
  sx0 = cst->transXtoCX(0.0) - cst->transHorizontalLtoCL(layer_length/2.0); 
  sy0 = cst->transYtoCY(offset) - cst->transVerticalLtoCL(layer_hight/2.0);

  double CLL = cst->transHorizontalLtoCL(blengthL);
  double CLR = cst->transHorizontalLtoCL(blengthR);
  double CH = cst->transVerticalLtoCL(bhight);
  

  for (int i = 0; i<n; i++)
  {
    if (i < n/2)
    {
      block[i] = new GlassBlock(i, 1, sx0, sy0+i*CH, CLL, CH);
    }

    else
    {
      block[i] = new GlassBlock(i, 2, sx0+CLL, sy0+(i-n/2)*CH, CLR, CH);
    }
  }

  title = new TLatex(sx0 + (CLL+CLR)*0.01, sy0+CH*n/2.0+CH*0.1, ime);
  title->SetTextSize(0.025);
  title->Draw();  
 
  for(int i = 0; i<MAX_TRACK_NUM; i++) track_circ[i] = new TEllipse(0,0,0);

  cout<<"Calorimeter is created!"<<endl;
}


Calorimeter::~Calorimeter()
{

}


void Calorimeter::blockHit(int num, double adc)
{

  if (num<N) block[num]->ADChit(adc);
  else
  { 
#if DEBUG_LEVEL >= 3	
    cout<<"There is no block with this index!"<<endl;
#endif
  }
}

void Calorimeter::clear()
{
  for(int i = 0; i<N; i++) block[i]->clear();

  for (int i = 0; i<MAX_TRACK_NUM; i++)
  {
    track_circ[i]->SetX1(0.0);
    track_circ[i]->SetY1(0.0);
    track_circ[i]->SetR1(0.0);
    track_circ[i]->SetR2(0.0);
    track_circ[i]->SetFillColor(kWhite);
    track_circ[i]->Draw();

    delete track_index[i];
  }
}


void Calorimeter::Track(double x, double y, int i)
{
#if DEBUG_LEVEL >= 3	
	cout<<"HURA: TRACK: (x,y): "<<x<<", "<<y<<endl;
#endif
	// First we need to transform meters to pixels
	double CX =  cst->transXtoCX(-y);
   	double CY =  cst->transYtoCY(-x);	

	track_circ[i]->SetX1(CX);
	track_circ[i]->SetY1(CY);
	track_circ[i]->SetR1(0.008);
	track_circ[i]->SetR2(0.008);
	track_circ[i]->SetLineColor(1+i);
	track_circ[i]->SetLineWidth(2);
	//track_circ[i]->SetFillColor(kOrange+0-i);
     	track_circ[i]->Draw();

}


