//************************************************************************* 
//  Cherenkov.h - 7/31/2012
// 
//  by tadejd
// 
//  This class is used to create planar view of Cherenkov detector (mirror plane).
//
//
//*************************************************************************  

#include "TMath.h"
#include <cstring>
#include <cstdio>
#include <iostream>
#include <sstream>

#include "Cherenkov.h"

#define DEBUG_LEVEL 0

using namespace std;



Cherenkov::Cherenkov(char *ime, int nx, int ny, double plength, double phight, CStransform *trans)
{
  //Variables plength in plength (plane) are in [m]. Now we need to transform these to variables
  // from meters to pixels.

  cst = trans;
  Nx = nx;//number of mirrors in horizontal direction
  Ny = ny;//number of mirrors in vertical
  plane_length = plength;
  plane_hight = phight;

  // now we make proper transformation to get to the left upper corner.
  sx0 = cst->transXtoCX(0.0) - cst->transHorizontalLtoCL(plane_length/2.0); 
  sy0 = cst->transYtoCY(0.0) + cst->transVerticalLtoCL(plane_hight/2.0);

  double CL = cst->transHorizontalLtoCL(plane_length/Nx);
  double CH = cst->transVerticalLtoCL(plane_hight/Ny);

/*prvi način
  //left side
  for (int i = 0; i<n/2; i++)
  {
    mirror[i] = new Mirror(i, 1, sx0, sy0-CH*(i+1), CL, CH);
  }

  //right side
  for (int i = n/2; i<n; i++)
  {
    mirror[i] = new Mirror(i, 2, sx0+CL, sy0-CH*(i+1), CL, CH);
  }
*/
  int n = Nx*Ny;
  int counter = 1;

  for (int i = 0; i<n; i++)
  {
    if (i % 2 == 0) mirror[i] = new Mirror(i, 1, sx0, sy0-CH*counter, CL, CH);
    else
    {
      mirror[i] = new Mirror(i, 2, sx0+CL, sy0-CH*counter, CL, CH);
      counter += 1;
    }
  }

  title = new TLatex(sx0 + CL*0.02, sy0+CH*0.05, ime);
  title->SetTextSize(0.025);
  title->Draw();  

  for(int i = 0; i<MAX_TRACK_NUM; i++)track_circ[i] = new TEllipse(0,0,0);

   cout<<"Cherenkov detector is created!"<<endl;
}


Cherenkov::~Cherenkov()
{

}


void Cherenkov::mirrorHit(int num, double tdc, double adc)
{
  int n = Nx*Ny;

  if (num<n)
  {
    mirror[num]->hit(tdc);
    mirror[num]->ADChit(adc);
  }
  else
  { 
#if DEBUG_LEVEL >= 3	
    cout<<"There is no mirror with this index!"<<endl;
#endif
  }
}

void Cherenkov::Track(double x, double y, int i)
{

#if DEBUG_LEVEL >= 3	
	cout<<"HURA: TRACK: (x,y): "<<x<<", "<<y<<endl;
#endif
	// First we need to transform meters to pixels
	double CX =  cst->transXtoCX(-y);
   	double CY =  cst->transYtoCY(-x);	

	track_circ[i]->SetX1(CX);
	track_circ[i]->SetY1(CY);
	track_circ[i]->SetR1(0.008);
	track_circ[i]->SetR2(0.008);
	track_circ[i]->SetLineColor(1+i);
	track_circ[i]->SetLineWidth(2);
	//track_circ[i]->SetFillColor(kOrange+0-i);
     	track_circ[i]->Draw();

}


void Cherenkov::clear()
{
  int n = Nx*Ny; 

  for (int i = 0; i<n; i++) mirror[i]->clear();
 
  for (int i = 0; i<MAX_TRACK_NUM; i++)
	{
          track_circ[i]->SetX1(0.0);
	  track_circ[i]->SetY1(0.0);
	  track_circ[i]->SetR1(0.0);
	  track_circ[i]->SetR2(0.0);
	  track_circ[i]->SetFillColor(kWhite);
     	  track_circ[i]->Draw();

	  delete track_index[i];
	}
}


















