
//************************************************************************* *
//  EVe.cxx  - 4/14/2008 (changed for HRS-L 8/8/2012 by tadejd)
// 
//  by miham
// 
//  This is the main class of the event display. 
// 
//
//**************************************************************************
 

#include "EVe.h"
#include "TMath.h"
#include "TAxis.h"
#include "TGaxis.h"
#include "TF1.h"
#include <cstring>
#include <cstdio>
#include <iostream>
#include <sstream>
#include <TApplication.h>
#include <TROOT.h>

#include "EVe_DB.h"

#define DEBUG_LEVEL  0


using namespace std;


EVe::EVe(const TGWindow *p, UInt_t w, UInt_t h)
{
   // main frame
   fMainFrame = new TGMainFrame(p, w, h, kMainFrame | kVerticalFrame);
   fMainFrame->SetLayoutBroken(kTRUE);
   fMainFrame->SetWindowName("Event ViewEr - EVE");
   fMainFrame->Connect("CloseWindow()", "EVe", this, "MyCloseWindow()");

   // embedded canvas
   fRootEmbeddedCanvas = new TRootEmbeddedCanvas(0,fMainFrame,h+250, h-16);
   Int_t wfRootEmbeddedCanvas = fRootEmbeddedCanvas->GetCanvasWindowId();
   c1 = new TCanvas("c1", 10, 10, wfRootEmbeddedCanvas);
   c2 = new TCanvas("c2", 10, 10, wfRootEmbeddedCanvas);
   c3 = new TCanvas("c3", 10, 10, wfRootEmbeddedCanvas);
   c4 = new TCanvas("c4", 10, 10, wfRootEmbeddedCanvas);
   c5 = new TCanvas("c5", 10, 10, wfRootEmbeddedCanvas);
   fMainFrame->AddFrame(fRootEmbeddedCanvas, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fRootEmbeddedCanvas->MoveResize(8,8,h+250,h-16);


   //________________________ Buttons___________________________________

   fNumberEntry1 = new TGNumberEntry(fMainFrame, (Double_t) 0,8,-1,(TGNumberFormat::EStyle) 5);
   fMainFrame->AddFrame(fNumberEntry1, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fNumberEntry1->MoveResize(w - 260, 350,100,30);

   TGTextButton *fTextButtonSE = new TGTextButton(fMainFrame,"Show this Event");
   fMainFrame->AddFrame(fTextButtonSE, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fTextButtonSE->MoveResize(w-150, 350,100,30);

   TGTextButton *fTextButtonNext = new TGTextButton(fMainFrame,"Next");
   fMainFrame->AddFrame(fTextButtonNext, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fTextButtonNext->MoveResize(w-150, 390,100,30);

   TGTextButton *fTextButtonPrevious = new TGTextButton(fMainFrame,"Previous");
   fMainFrame->AddFrame(fTextButtonPrevious, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fTextButtonPrevious->MoveResize(w -260, 390 ,100,30);

   TGTextButton *fTextButtonNextGood = new TGTextButton(fMainFrame,"Next Good");
   fMainFrame->AddFrame(fTextButtonNextGood, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fTextButtonNextGood->MoveResize(w - 150, 430, 100,30);

   TGTextButton *fTextButtonPreviousGood = new TGTextButton(fMainFrame,"Previous Good");
   fMainFrame->AddFrame(fTextButtonPreviousGood, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fTextButtonPreviousGood->MoveResize(w - 260, 430, 100,30);


   TGTextButton *fTextButtonExit = new TGTextButton(fMainFrame,"E&xit","gApplication->Terminate(0)");
   fMainFrame->AddFrame(fTextButtonExit, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fTextButtonExit->MoveResize(w-150, h-50,100,30);

   TGTextButton *fTextButtonPrint = new TGTextButton(fMainFrame,"&Print");
   fMainFrame->AddFrame(fTextButtonPrint, new TGLayoutHints(kLHintsLeft | kLHintsTop,2,2,2,2));
   fTextButtonPrint->MoveResize(w-260, h-50,100,30);

   fMainFrame->MapSubwindows();
   fMainFrame->Resize(fMainFrame->GetDefaultSize());
   fMainFrame->MapWindow();
   fMainFrame->Resize(w,h);


   EventNumber = 0;

   fTextButtonNext->Connect("Clicked()", "EVe", this, "doNext()");
   fTextButtonPrevious->Connect("Clicked()", "EVe", this, "doPrevious()");
   fTextButtonSE->Connect("Clicked()", "EVe", this, "doThis()");
   fTextButtonNextGood->Connect("Clicked()", "EVe", this, "doNextGood()");
   fTextButtonPreviousGood->Connect("Clicked()", "EVe", this, "doPreviousGood()");
   fTextButtonPrint->Connect("Clicked()", "EVe", this, "PrintToFile()");

  
   CreateWires();

   cout<<"EVe created!!!"<<endl;

}

EVe::~EVe()
{
  fMainFrame->Cleanup();
  delete fMainFrame;
}


void EVe::MyCloseWindow()
{
  fMainFrame->SendCloseMessage();
  gApplication->Terminate();
}


void EVe::CreateWires()//planar view
{
   fRootEmbeddedCanvas->AdoptCanvas(c3);
   c3->cd();
   c3->Clear();

   CStransform *vdc1_cst = new CStransform(canvas_length, canvas_height, canvas_VDC1_posx, canvas_VDC1_posy);
   CStransform *vdc2_cst = new CStransform(canvas_length, canvas_height, canvas_VDC2_posx, canvas_VDC2_posy);
   CStransform *S1_cst = new CStransform(canvas_length, canvas_height, canvas_S1_posx, canvas_S1_posy);
   CStransform *S2m_cst = new CStransform(canvas_length, canvas_height, canvas_S2m_posx, canvas_S2m_posy);
   CStransform *cher_cst = new CStransform(canvas_length, canvas_height, canvas_CHER_posx, canvas_CHER_posy);
   CStransform *cal1_cst = new CStransform(canvas_length, canvas_height, canvas_CAL1_posx, canvas_CAL1_posy);
   CStransform *cal2_cst = new CStransform(canvas_length, canvas_height, canvas_CAL2_posx, canvas_CAL2_posy);

   vdc1 = new VDCChamber((char*)"VDC-1", VDC1_U_WN, L1, H1, vdc1_cst, 0.0);
   vdc2 = new VDCChamber((char*)"VDC-2", VDC2_U_WN, L2, H2, vdc2_cst, VDC2_offset);
  
   sS1 = new ScintilationPlane((char*)"S1-plane", S1_PN, S1_length, S1_height, S1_cst);
   sS2m = new ScintilationPlane((char*)"S2m-plane", S2m_PN, S2m_length, S2m_height, S2m_cst);

   cher = new Cherenkov((char*) "Cherenkov", CHER_MNx, CHER_MNy, CHER_length, CHER_hight, cher_cst);

   cal1 = new Calorimeter((char*) "First layer", CAL1_BN, CAL_length1, CAL_length2, CAL_hight, 0.0, cal1_cst);
   cal2 = new Calorimeter((char*) "Second layer", CAL2_BN, CAL_length2, CAL_length1, CAL_hight, CAL2_offset, cal2_cst);
   

   // In the end we plot a coordinate system

   TArrow *xaxis = new TArrow(0.95, 0.1, 0.95, 0.02, 0.02, "|>");
   xaxis->Draw();
   TArrow *yaxis = new TArrow(0.95, 0.1, 0.82, 0.1, 0.02, "|>");
   yaxis->Draw();

   TLatex *xtext = new TLatex(0.965,0.03, "x");
   xtext->SetTextSize(0.025);
   xtext->Draw();  

   TLatex *ytext = new TLatex(0.83, 0.07, "y");
   ytext->SetTextSize(0.025);
   ytext->Draw();


   // lets draw a scale

 
   TF1 *f1 = new TF1("f1","x",0.0,0.474);
   f1->GetParameter(0); //to get rid of: warning: unused variable ‘f1’ 
   TGaxis *A1 = new TGaxis(0.05, 0.95, 0.14, 0.95, "f1",1103);
   A1->SetLabelSize(0.017);
   A1->Draw("same");

   TF1 *f2 = new TF1("f2","x",0.474,1.2873);
   f2->GetParameter(0);
   TGaxis *A2 = new TGaxis(0.14, 0.95, 0.25, 0.95, "f2",303);
   A2->SetLabelSize(0.017);
   //A2->SetMaxDigits(2);
   A2->Draw("same");

   TF1 *f3 = new TF1("f3","x",1.2873, 2.72);
   f3->GetParameter(0);
   TGaxis *A3 = new TGaxis(0.25, 0.95, 0.5, 0.95, "f3",103);
   A3->SetLabelSize(0.017);
   //A3->SetMaxDigits(3);
   A3->Draw("same");
   

   TF1 *f4 = new TF1("f4","x",2.72, 3.1415); 
   f4->GetParameter(0);
   TGaxis *A4 = new TGaxis(0.5, 0.95, 0.65, 0.95, "f4",103);
   A4->SetLabelSize(0.017);
   //A4->SetMaxDigits(3);
   A4->Draw("same");
   

   TF1 *f5 = new TF1("f5","x", 3.1415, 3.75);
   f5->GetParameter(0);
   TGaxis *A5 = new TGaxis(0.65, 0.95, 0.8, 0.95, "f5",203);
   A5->SetLabelSize(0.017);
   //A5->SetMaxDigits(3);
   A5->Draw("same");
   A5->SetTitleSize(0.02);

   TF1 *f6 = new TF1("f6","x", 3.75, 3.90);
   f6->GetParameter(0);
   TGaxis *A6 = new TGaxis(0.8, 0.95, 0.93, 0.95, "f6",303);
   A6->SetLabelSize(0.017);
   //A6->SetMaxDigits(3);
   A6->Draw("same");
   A6->SetTitle("z [m]");
   A6->SetTitleSize(0.02);


   for (int q = 0; q<100; q++) plTrack[q] = new PlanarTrack();


   c3->Update();
}

void EVe::initRun(int nrun, char *filename)
{
   cout << "Reading file " << endl;
   TFile *f1 = new TFile(filename, "r");
   t1 = (TTree*) f1->Get("T");
   TotalNumberOfEvents =  t1->GetEntries();

   run_number = nrun;    

#if DEBUG_LEVEL >= 3
   cout<<"Number of Entries is: "<<TotalNumberOfEvents<<endl;
#endif

  // Now we read all data

  t1->SetBranchAddress( "L.vdc.u1.nhit", &L_vdc_u1_nhit);
  t1->SetBranchAddress( "L.vdc.u2.nhit", &L_vdc_u2_nhit);

  t1->SetBranchAddress( "L.vdc.v1.nhit", &L_vdc_v1_nhit);
  t1->SetBranchAddress( "L.vdc.v2.nhit", &L_vdc_v2_nhit);
  
  // U-wire plane

  t1->SetBranchAddress("L.vdc.u1.wire", &L_vdc_u1_wire);
  t1->SetBranchAddress("L.vdc.u2.wire", &L_vdc_u2_wire);

  t1->SetBranchAddress("L.vdc.u1.time", &L_vdc_u1_time);
  t1->SetBranchAddress("L.vdc.u2.time", &L_vdc_u2_time);
  
  // V-wire plane
  
  t1->SetBranchAddress("L.vdc.v1.wire", &L_vdc_v1_wire);
  t1->SetBranchAddress("L.vdc.v2.wire", &L_vdc_v2_wire);

  t1->SetBranchAddress("L.vdc.v1.time", &L_vdc_v1_time);
  t1->SetBranchAddress("L.vdc.v2.time", &L_vdc_v2_time);
  
  //track

  t1->SetBranchAddress( "L.tr.n", &L_tr_n);
  t1->SetBranchAddress( "L.tr.x", &L_tr_x);
  t1->SetBranchAddress( "L.tr.y", &L_tr_y);
  t1->SetBranchAddress( "L.tr.ph", &L_tr_ph);
  t1->SetBranchAddress( "L.tr.th", &L_tr_th);

  // variables for scintilation plane

  t1->SetBranchAddress( "L.s1.nthit", &L_s1_nthit);
  t1->SetBranchAddress( "L.s1.lt", &L_s1_lt);
  t1->SetBranchAddress( "L.s1.rt", &L_s1_rt);
  t1->SetBranchAddress( "L.s1.y_t", &L_s1_y_t);
  t1->SetBranchAddress( "L.s1.t_pads", &L_s1_t_pads);

  t1->SetBranchAddress( "L.s1.la", &L_s1_la);
  t1->SetBranchAddress( "L.s1.ra", &L_s1_ra);
  
  t1->SetBranchAddress( "L.s2.nthit", &L_s2_nthit);
  t1->SetBranchAddress( "L.s2.lt", &L_s2_lt);
  t1->SetBranchAddress( "L.s2.rt", &L_s2_rt);
  t1->SetBranchAddress( "L.s2.y_t", &L_s2_y_t);
  t1->SetBranchAddress( "L.s2.t_pads", &L_s2_t_pads);

  t1->SetBranchAddress( "L.s2.la", &L_s2_la);
  t1->SetBranchAddress( "L.s2.ra", &L_s2_ra); 

  // varibles for cherenkov detector

  t1->SetBranchAddress( "L.cer.nthit", &L_cer_nthit);
  t1->SetBranchAddress( "L.cer.t", &L_cer_t);
  t1->SetBranchAddress("L.cer.a", &L_cer_a);

  // variables for calorimeter

  t1->SetBranchAddress( "L.prl1.a", &L_prl1_a);
  t1->SetBranchAddress( "L.prl2.a", &L_prl2_a);


}

void EVe::DoDraw(int event)
{
  t1->GetEntry(event);


  TString Buff;
  if(event==0) {
    Buff = "";
   } else {
   Buff = "Run #";
   Buff += run_number;
   Buff += ", Event #";
   Buff += event;
   }
   graph_title = Buff.Data();
   //cout<<"Char #: "<<graph_title<<endl;
  


//_________________________ Lets handle Planar view  ______________________________

    c3->cd();

   
    if (title != NULL) delete title;
    title = new TLatex(0.02,0.02, graph_title);
    title->SetTextSize(0.03);
    title->Draw();   


    //***************** First Chamber

   
   
#if DEBUG_LEVEL >= 3
    cout<<"Plane U1 has been hit ... times: "<<L_vdc_u1_nhit<<endl;
    cout<<"Plane V1 has been hit ... times: "<<L_vdc_v1_nhit<<endl;
#endif

    vdc1->clear();
    for(int i = 0; i<L_vdc_u1_nhit; i++)
    {
#if DEBUG_LEVEL >= 3
	cout<<"Wire u1 : "<<i<<" je: "<<L_vdc_u1_wire[i]<<endl;
#endif
        vdc1->uWireHit(L_vdc_u1_wire[i]);
    } 

    for(int i = 0; i<L_vdc_v1_nhit; i++)
    {
#if DEBUG_LEVEL >= 3
	cout<<"Wire v1 : "<<i<<" je: "<<L_vdc_v1_wire[i]<<endl;
#endif
        vdc1->vWireHit(L_vdc_v1_wire[i]);
    } 

    //***************** Second Chamber

#if DEBUG_LEVEL >= 3
    cout<<"Plane U2 has been hit ... times: "<<L_vdc_u2_nhit<<endl;
    cout<<"Plane V2 has been hit ... times: "<<L_vdc_v2_nhit<<endl;
#endif

    vdc2->clear();
    for(int i = 0; i<L_vdc_u2_nhit; i++)
    {
#if DEBUG_LEVEL >= 3
	cout<<"Wire u2 : "<<i<<" je: "<<L_vdc_u2_wire[i]<<endl;
#endif
        vdc2->uWireHit(L_vdc_u2_wire[i]);
    } 

    for(int i = 0; i<L_vdc_v2_nhit; i++)
    {
#if DEBUG_LEVEL >= 3
	cout<<"Wire v2 : "<<i<<" je: "<<L_vdc_v2_wire[i]<<endl;
#endif
        vdc2->vWireHit(L_vdc_v2_wire[i]);
    } 

    //******** Now scintillaion planes

#if DEBUG_LEVEL >= 3
   cout<<"*!* S1 - nthit: "<<L_s1_nthit<<", S2m - nthit: "<<L_s2_nthit<<endl;
#endif

   double S1bar_ypos[S1_PN];
   double S2mbar_ypos[S2m_PN];

   for (int q = 0; q<S1_PN; q++) S1bar_ypos[q] = 0.0;
   for (int q = 0; q<S2m_PN; q++) S2mbar_ypos[q] = 0.0;
	
   for (Int_t q = 0; q<L_s1_nthit; q++)
   {
	int bar = (int)(L_s1_t_pads[q]);
        double ypos = L_s1_y_t[q];
	S1bar_ypos[bar] = ypos;
#if DEBUG_LEVEL >= 3
	cout<<"--> Bar S1: "<<bar<<" Y pos: "<<ypos<<endl;
#endif
   }
   
   for (Int_t q = 0; q<L_s2_nthit; q++)
   {
	int bar = (int)(L_s2_t_pads[q]);
        double ypos = L_s2_y_t[q];
	S2mbar_ypos[bar] = ypos;
#if DEBUG_LEVEL >= 3
	cout<<"--> Bar S2m "<<bar<<" Y pos: "<<ypos<<endl;
#endif
   }

    sS1->clear();
    sS2m->clear();
    for (int i = 0; i<S1_PN; i++)
    {
#if DEBUG_LEVEL >= 3
	cout<<"| S1 -L: "<<L_s1_lt[i]<<" S1 - R: "<<L_s1_rt[i]<<".....YPOS: "<<S1bar_ypos[i]<<" |"<<endl;
#endif

	sS1->paddleHit(i,L_s1_lt[i], L_s1_rt[i], -S1bar_ypos[i], L_s1_la[i], L_s1_ra[i]);
    }  

    for (int i = 0; i<S2m_PN; i++)
    {
#if DEBUG_LEVEL >= 3
	cout<<"| S2m -L: "<<L_s2_lt[i]<<" S2m - R: "<<L_s2_rt[i]<<".....YPOS:"<<S2mbar_ypos[i]<<"|"<<endl;
#endif

	sS2m->paddleHit(i, L_s2_lt[i], L_s2_rt[i], -S2mbar_ypos[i], L_s2_la[i], L_s2_ra[i]);	
    }  

//**************** Now Cherenkov detector **************

  cher->clear();
  int n = CHER_MNx*CHER_MNy;  

  for (int i = 0; i<n; i++)
  {
    cher->mirrorHit(i, L_cer_t[i], L_cer_a[i]); 
  }


//************** Now Calorimeters ********************

  cal1->clear();
  cal2->clear();
  
  for (int i = 0; i<CAL1_BN; i++)
  {
    cal1->blockHit(i,L_prl1_a[i]);
  }

  for (int i = 0; i<CAL2_BN; i++)
  {
    cal2->blockHit(i,L_prl2_a[i]);
  }
    

  


//---------------------- Now we draw Trajectories through detectors-------------------------------------------------------
 


    for (int q = 0; q<100; q++) plTrack[q]->Clear();
     

    if (L_tr_n> 0)
    {		
	CStransform *vdc1_cst = new CStransform(canvas_length, canvas_height, canvas_VDC1_posx, canvas_VDC1_posy);
   	CStransform *vdc2_cst = new CStransform(canvas_length, canvas_height, canvas_VDC2_posx, canvas_VDC2_posy);
   	CStransform *S1_cst = new CStransform(canvas_length, canvas_height, canvas_S1_posx, canvas_S1_posy);
   	CStransform *S2m_cst = new CStransform(canvas_length, canvas_height, canvas_S2m_posx, canvas_S2m_posy);
        CStransform *cher_cst = new CStransform(canvas_length, canvas_height, canvas_CHER_posx, canvas_CHER_posy);
        CStransform *cal1_cst = new CStransform(canvas_length, canvas_height, canvas_CAL1_posx, canvas_CAL1_posy);
        CStransform *cal2_cst = new CStransform(canvas_length, canvas_height, canvas_CAL2_posx, canvas_CAL2_posy);

	for(int q = 0; q<L_tr_n; q++)
	{
		double x0 = L_tr_x[q];//x coordinate in detector coordinate system (z coordinate is ideal trayectory through detector)
		double y0 = L_tr_y[q];//y coordinate in detector coordinate system
 		double th = L_tr_th[q];
		double ph = L_tr_ph[q];

                double koef = 2.0/sqrt(2.0);//cos(45)^-1
    
                /// VDC komore
  
		double z1 = VDC2_z;//distance between chamber in detector coordinate system
		double x1 = x0 + th*z1;//x coordinate of second chamber
		double y1 = y0 + ph*z1;//y coordinate of second chamber

  
#if DEBUG_LEVEL >= 3
		cout<<"Q: "<<q<<endl;
		cout<<"~~~~~>th0: "<<th<<", ph0: "<<ph<<endl;
		cout<<"~~~~~>x0: "<<x0<<", y0: "<<y0<<endl;
		cout<<"~~~~~>x1: "<<x1<<", y1: "<<y1<<endl;
#endif

                double x0p = x0*koef;//projection of x on VDC1 plane
                double x1p = x1*koef;//projection of x on VDC2 plane                

		vdc1->Track(0.9*x0p,y0,q);//I reduce x coordinate in tracks for better picture
		vdc2->Track(0.9*x1p,y1,q);

                // S1
                double z2 = S1_z;
		double x2 = x0 + th*z2;
		double y2 = y0 + ph*z2 + S1_tr;

#if DEBUG_LEVEL >= 3	
		cout<<"~~~~~>x2: "<<x2<<", y2: "<<y2<<endl;
#endif
		sS1->Track(0.8*x2,y2,q);

                // Cherenkov
                double z3 = CHER_z;
                double x3 = x0 + th*z3;
                double y3 = y0 + ph*z3;

#if DEBUG_LEVEL >= 3	
		cout<<"~~~~~>x3: "<<x3<<", y3: "<<y3<<endl;
#endif

                cher->Track(0.8*x3,y3,q);

 
                //S2m
		double z4 = S2m_z;
		double x4 = x0 + th*z4;
		double y4 = y0 + ph*z4 + S2m_tr;


#if DEBUG_LEVEL >= 3	
		cout<<"~~~~~>x4: "<<x4<<", y4: "<<y4<<endl;
#endif
		sS2m->Track(0.85*x4,y4,q);

                // Cal 1
                double z5 = CAL1_z;
                double x5 = x0 + th*z5;
                double y5 = y0 + ph*z5;

#if DEBUG_LEVEL >= 3	
		cout<<"~~~~~>x5: "<<x5<<", y5: "<<y5<<endl;
#endif
                cal1->Track(0.8*x5,y5,q);

              
               //Cal 2
               double z6 = CAL2_z;
               double x6 = x0 + th*z6;
               double y6 = y0 + ph*z6;

#if DEBUG_LEVEL >= 3	
		cout<<"~~~~~>x6: "<<x6<<", y6: "<<y6<<endl;
#endif
                cal2->Track(0.9*x6,y6,q);
                
                plTrack[q]->DrawMe(vdc1_cst, 0.9*x0p, y0, vdc2_cst, 0.9*x1p, y1, S1_cst, 0.8*x2, y2, cher_cst, 0.8*x3, y3, S2m_cst, 0.85*x4, y4, cal1_cst,
                            0.8*x5, y5, cal2_cst, 0.9*x6, y6);
	
	}
   
    }
    c3->Draw();
    c3->Update();

}

void EVe::doThis()
{
  EventNumber = fNumberEntry1->GetNumber();
  if (EventNumber<TotalNumberOfEvents && EventNumber>0)
  {
    DoDraw(EventNumber);
  }  
}

void EVe::doNext()
{

  EventNumber = fNumberEntry1->GetNumber();
  if (EventNumber<TotalNumberOfEvents)
  {
    EventNumber++;
    fNumberEntry1->SetNumber(EventNumber); 
    DoDraw(EventNumber);
  } 
}
void EVe::doPrevious()
{
  EventNumber = fNumberEntry1->GetNumber();
  if (EventNumber>0)
  {
    EventNumber--;
    fNumberEntry1->SetNumber(EventNumber);
    DoDraw(EventNumber);
  }  
}


void EVe::doNextGood()
{
  EventNumber = fNumberEntry1->GetNumber();  // Start at this ev. number
  while (EventNumber<TotalNumberOfEvents) 
  {
    EventNumber++; // rise the number for one;
    t1->GetEntry(EventNumber);
    fNumberEntry1->SetNumber(EventNumber); // write that to the display 
    if (L_tr_n > 0.0) // check if event is good (if there is at least 1 good track).
    { 
	DoDraw(EventNumber);
	break;
    }
  }  
}

void EVe::doPreviousGood()
{
  EventNumber = fNumberEntry1->GetNumber();  // Start at this ev. number
  while (EventNumber>0) 
  {
    EventNumber--; // lower the number for one;
    t1->GetEntry(EventNumber);
    fNumberEntry1->SetNumber(EventNumber); // write that to the display 
    if (L_tr_n > 0.0) // check if event is good (if there is at least 1 good track).
    { 
	DoDraw(EventNumber);
	break;
    }
  }  
}

void EVe::PrintToFile()
{
  // Routine written by Bryan Mofitt
  TCanvas *fCanvas = fRootEmbeddedCanvas->GetCanvas();
  gStyle->SetPaperSize(20,24);
  static TString dir("printouts");
  TGFileInfo fi;
  const char *myfiletypes[] = 
    { "All files","*",
      "PostScript files","*.ps",
      "Encapsulated PostScript files","*.eps",
      "GIF files","*.gif",
      "JPG files","*.jpg",
      0,               0 };
  fi.fFileTypes = myfiletypes;
  fi.fIniDir    = StrDup(dir.Data());

  new TGFileDialog(gClient->GetRoot(), fMainFrame, kFDSave, &fi);
  if(fi.fFilename!=NULL) fCanvas->Print(fi.fFilename);
}





