//**************************************************************************
//  EVe_DB.h  - 8/8/2012
// 
//  by tadejd
// 
//  This file contains all data regarding the HRS-L spectrometer
//  (distances, sizes, wire numbers, etc.)
// 
//
//**************************************************************************

#ifndef ROOT_EVe_DB
#define ROOT_EVe_DB

// 1. VDC variables

	/// Height of the first chamber  
    	const double H1 = 2.118;

	/// Length of the first chamber
	const double L1 = 0.288;

	/// Wire number per plane 
	const int VDC1_U_WN = 368;

	const int VDC1_V_WN = 368;


// 2. VDC variables

	/// Height of the second chamber 	
    	const double H2 = 2.118; 

	/// Length of the second chamber
	const double L2 = 0.288;

	/// Distance between the begining of the first chamber and 
	/// the beginning of the second
	const double VDC2_z = 0.474;

        /// offset in y direction
        const double VDC2_offset = 0.0;//0.230;


	/// Wire number per plane 
	const int VDC2_U_WN = 368;

	const int VDC2_V_WN = 368;

// S1-plane variables

	/// number of paddles
	const int S1_PN  = 6;
	
	/// Paddle length
	const double S1_length = 0.355;

	/// Paddle height
	const double S1_height = 0.295;

        /// Distance between the begining of the first chamber and 
	/// the beginning of the S1 scintillation plane;
	const double S1_z = 1.2873;

        /// Y offset (for track)
        const double S1_tr = -0.129;
	 
	
// S2m-plane variables

	/// number of paddles
	const int S2m_PN  = 16;

	/// Paddle length
	const double S2m_length = 0.432;
        
	/// Paddle height
	const double S2m_height = 0.14;
       
	/// Distance between the begining of the first chamber and 
	/// the beginning of the S2m scintillation plane;
	const double S2m_z = 3.1415;
 
        /// Y offset (for track)
        const double S2m_tr = -0.11;


// Cherenkov detector variables

        /// number of mirrors in horizontal direction
        const int CHER_MNx = 2;

        /// number of mirrors in vertical direction
        const int CHER_MNy = 5; 

        /// Mirror length
        const double CHER_length = 0.8;

        /// Mirror hight
        const double CHER_hight = 2.5;

        /// Distance between the begining of the first chamber and 
	/// the plane or mirrors in cherenkov detector;
	const double CHER_z = 2.72;

// Calorimeter variables

        /// number of blocks in first layer
        const int CAL1_BN = 34;

        /// number of blocks in second layer
        const int CAL2_BN = 34;

        /// offset in y direction of second layer
        const double CAL2_offset = 0.05;

        /// Block length1
        const double CAL_length1 = 0.35;

        /// Block length2
        const double CAL_length2 = 0.3;

        /// Block hight
        const double CAL_hight = 0.145;

        /// Distance between the begining of the first chamber and 
	/// the beginning of first/second layer;
	const double CAL1_z = 3.75;
        const double CAL2_z = 3.90;


// Planar view variables

	/// Canvas length equivalent in meters (actual size of spectrometer is around 4 m)
	const double canvas_length = 10.0; //5.5;  //4.0;
	const double canvas_height = 3.3;

	/// Position of the 1. VDC inside a canvas in pixels
	const double canvas_VDC1_posx = 0.05; 
	const double canvas_VDC1_posy = 0.5;

	/// Position of the 2. VDC inside a canvas in pixels
	const double canvas_VDC2_posx = 0.14; 
	const double canvas_VDC2_posy = 0.5;

	/// Position of the S1-plane inside a canvas in pixels
	const double canvas_S1_posx = 0.25; 
	const double canvas_S1_posy = 0.5;

	/// Position of the S2m-plane inside a canvas in pixels
	const double canvas_S2m_posx = 0.63; 
	const double canvas_S2m_posy = 0.5;

        /// Position of Cherenkov detector inside a canvas in pixles
        const double canvas_CHER_posx = 0.5;
        const double canvas_CHER_posy = 0.5;

        /// Position of first layer inside a canvas in pixles
        const double canvas_CAL1_posx = 0.78;
        const double canvas_CAL1_posy = 0.5;

        /// Position of second layer inside a canvas in pixles
        const double canvas_CAL2_posx = 0.91;
        const double canvas_CAL2_posy = 0.5;
 

// Technical Variables for internal puposes of ev. display
	
	/// Maximum number of paddles in the scin. plane
	const int MAX_PADDLE_NUM =  100; 

        /// Maximum number of mirrors in cherenkov detector
        const int MAX_MIRROR_NUM = 100;

        /// Maximum number of blocks in calorimeter layer
        const int MAX_BLOCK_NUM = 50;

	const int MAX_ROADS_NUM =  500;
	const int MAX_TRACK_NUM =  77;
	const int MAX_HITS_NUM = 100;
        

#endif
