//************************************************************************* 
//  GlassBlock.cxx - 8/1/2012
// 
//  by tadejd
// 
//  This class is used to create planar view of one glass block in calorimeter.
//
//
//*************************************************************************  

#include "GlassBlock.h"
#include "TMath.h"
#include <cstring>
#include <cstdio>
#include <iostream>
#include <sstream>

#define DEBUG_LEVEL 0

using namespace std;

GlassBlock::GlassBlock(int index, int side, double x, double y, double a, double b)
{
  sx0 = x;
  sy0 = y;
  sa = a;
  sb = b;

//index of block; side->(1-left, 2-right); x,y->cooridnate of lower left corner; a,b->length, hight of block

//let's make left photomultiplier

if (side == 1)
  {

    Double_t px[8] = {sx0, sx0-0.3*a, sx0-0.3*a, sx0-0.5*a, sx0-0.5*a, sx0-0.3*a, sx0-0.3*a, sx0};
    Double_t py[8] = {sy0+0.1*b, sy0+0.2*b, sy0+0.33*b, sy0+0.35*b, sy0+0.65*b, sy0+0.67*b, sy0+0.8*b, sy0+0.9*b};
    pline = new TPolyLine(8,px,py);
    pline->SetFillColor(38);
    pline->SetLineColor(1);
    pline->SetLineWidth(1);
    pline->Draw("f");
    pline->Draw();

    pvline = new TLine(sx0-0.3*a, sy0+0.3*b, sx0-0.3*a, sy0+0.7*b);
    pvline->SetLineColor(kBlack);
    pvline->Draw();

  }

//let's make right photomultiplier

if (side == 2)
  {

    Double_t px[8] = {sx0+a, sx0+a+0.3*a, sx0+a+0.3*a, sx0+a+0.5*a, sx0+a+0.5*a, sx0+a+0.3*a, sx0+a+0.3*a, sx0+a};
    Double_t py[8] = {sy0+0.1*b, sy0+0.2*b, sy0+0.33*b, sy0+0.35*b, sy0+0.65*b, sy0+0.67*b, sy0+0.8*b, sy0+0.9*b};
    pline = new TPolyLine(8,px,py);
    pline->SetFillColor(38);
    pline->SetLineColor(1);
    pline->SetLineWidth(1);
    pline->Draw("f");
    pline->Draw();

    pvline = new TLine(sx0+a+0.3*a, sy0+0.3*b, sx0+a+0.3*a, sy0+0.7*b);
    pvline->SetLineColor(kBlack);
    pvline->Draw();
 
  }

//let's make block

  Double_t bx[5] = {sx0, sx0, sx0+a, sx0+a, sx0};
  Double_t by[5] = {sy0, sy0+b, sy0+b, sy0, sy0};
  bline = new TPolyLine(5, bx, by);
  bline->SetFillColor(38);
  bline->SetLineColor(1);
  bline->SetLineWidth(1);
  bline->Draw("f");
  bline->Draw();

  TString Buff;
  Buff="";
  Buff+=(index+1);
  const char *ime = Buff.Data();

#if DEBUG_LEVEL >= 3	
   cout<<"Ime je: "<<ime<<endl;
#endif

  if (side == 1)
  {
    index_text = new TLatex(x-a, y+b*0.01, ime);
    index_text->SetTextSize(0.025);
    index_text->Draw();
  }
 
  if (side == 2)
  {
    index_text = new TLatex(x+1.5*a, y+b*0.01, ime);
    index_text->SetTextSize(0.025);
    index_text->Draw();
  } 

  
#if DEBUG_LEVEL >= 3	
   cout<<"Block of glass with photomultiplier is created!"<<endl;
#endif

}

GlassBlock::~GlassBlock()
{

}

void GlassBlock::ADChit(double adc)
{

  double min = 0.0;
  if (adc > min)
  {
    pline->SetFillColor(kGreen);
    double radius = 0.0006792*sqrt(adc/3.141592654);
    CircleADC  = new TEllipse(sx0+sa/2.0, sy0+sb/2.0, radius, radius);
    CircleADC->SetLineColor(kOrange);
    CircleADC->SetLineWidth(2); 
    CircleADC->SetFillColor(kOrange);
    CircleADC->SetFillStyle(3003);
    CircleADC->Draw();
  }

}


void GlassBlock::clear()
{
  pline->SetFillColor(38); 
  delete CircleADC;
  CircleADC = new TEllipse(0.0, 0.0, 0.0, 0.0);
}



