//************************************************************************* 
//  Mirror.cxx  - 7/31/2012
// 
//  by tadejd
// 
//  This class is used to create planar view of one mirror and it's photomultiplier.
//
//
//*************************************************************************  

#include "Mirror.h"
#include "TMath.h"
#include <cstring>
#include <cstdio>
#include <iostream>
#include <sstream>

#define DEBUG_LEVEL 0

using namespace std;

Mirror::Mirror(int index, int side, double x, double y, double a, double b)
{
//index-index of mirror; side-left(1)/right(2) mirror; x,y coordinate of lower left corner of mirror; a,b - length, hight of mirror

  sx0 = x;
  sy0 = y;
  sa = a;
  sb = b;

  double dx = a/4.0;
  double dy = b/6.0; 

    //let's make mirror with 24 submirrors

    //frame
    Double_t xa[5] = {x, x, x+a, x+a, x};
    Double_t ya[5] = {y, y+b, y+b, y, y};
    pline = new TPolyLine(5,xa,ya);
    pline->SetFillColor(38);
    pline->SetLineColor(1);
    pline->SetLineWidth(1);
    pline->Draw("f");
    pline->Draw();
    
    //vertical lines
    for(int i = 1; i<4; i++)
    {       
      vline[i] = new TLine(x+i*dx, y, x+i*dx, y+b);
      vline[i]->SetLineColor(kGray);
      vline[i]->Draw();
    }

    //horizontal lines
    for(int i = 1; i<6; i++)
    {
      hline[i] = new TLine(x, y+i*dy, x+a, y+i*dy);
      hline[i]->SetLineColor(kGray);
      hline[i]->Draw();
    }

    //photomultiplier
    if (side == 1)//left
    {
      circ = new TEllipse(x-0.1*a, y+b, 0.1*a, 0.07*b);
      circ->SetFillColor(kGray);
      circ->Draw();
    }

    if (side == 2)//right
    {
      circ = new TEllipse(x+a+0.1*a, y+b, 0.1*a, 0.07*b);
      circ->SetFillColor(kGray);
      circ->Draw();
    }

  TString Buff;
  Buff="";
  Buff+=(index+1);
  const char *ime = Buff.Data();

#if DEBUG_LEVEL >= 3	
   cout<<"Ime je: "<<ime<<endl;
#endif
  if (side == 1)
  {
    index_text = new TLatex(x-0.3*a, y+b-0.21*b, ime);
    index_text->SetTextSize(0.025);
    index_text->Draw();
  }   


  if (side == 2)
  {
    index_text = new TLatex(x+a+0.1*a, y+b-0.2*b, ime);
    index_text->SetTextSize(0.025);
    index_text->Draw();
  }  

#if DEBUG_LEVEL >= 3	
   cout<<"Mirror is created!"<<endl;
#endif

}


Mirror::~Mirror()
{

}


void Mirror::hit(double tdc)
{
  double min = 0.0;
  if (tdc > min)
  { 
  circ->SetFillColor(kGreen);
  pline->SetFillColor(kGreen);
  }
}
    

void Mirror::ADChit(double adc)
{
  double min = 0.0;
  
  if (adc > min)
  {
    double radius = 0.0009792*sqrt(adc/3.141592654);
    CircleADC  = new TEllipse(sx0+sa/2.0, sy0+sb/2.0, radius, radius);
    CircleADC->SetLineColor(kOrange);
    CircleADC->SetLineWidth(2); 
    CircleADC->SetFillColor(kOrange);
    CircleADC->SetFillStyle(3003);
    CircleADC->Draw();
  }
}


void Mirror::clear()
{
  pline->SetFillColor(38);
  circ->SetFillColor(kGray);
  delete CircleADC;
  CircleADC = new TEllipse(0.0, 0.0, 0.0, 0.0);
}




































