
//************************************************************************* 
//  VDCChamber.cxx  - 4/14/2008  (7/25/2012 - for vdc by tadejd)
// 
//  by miham
// 
//  This class is used to create planar view of the VDC.
//
//
//*************************************************************************   

#include "VDCChamber.h"
#include "TMath.h"
#include <cstring>
#include <cstdio>
#include <iostream>
#include <sstream>

#define DEBUG_LEVEL 0


using namespace std;

VDCChamber::VDCChamber(char *ime, int n, double Length, double Hight, CStransform *trans, double offset)//Length = 0.288 m, Hight = 2.118 m
{

   cst = trans;

   double x =  cst->transXtoCX(0.0) - cst->transHorizontalLtoCL(Length)/2; //CX0,CY0 are in the middle of chamber; x,y lower left corner
   double y =  cst->transYtoCY(-offset) - cst->transVerticalLtoCL(Hight)/2;

#if DEBUG_LEVEL >= 3	
   cout<<"x "<<x<<" y "<<y<<endl;	
#endif

   double a = cst->transHorizontalLtoCL(Length); //length of chamber (trans)
   double b = cst->transVerticalLtoCL(Hight); //hight of chamber

   fa = a;
   fb = b;

   // n = actual number of wires
   // Num = number ow wires that we draw

   if ((n/5.0 - int(n/5.0))>0) Num =  (int) (n/5.0) + 1; // must be rounded up
   else Num = (int) (n/5.0);

#if DEBUG_LEVEL >= 3	
   cout<<"IMAMO n = "<<n<<", Num = "<<Num<<endl;
#endif

   Double_t xokvir[5] = {x-0.5*a, x-0.5*a, x+a+0.5*a, x+a+0.5*a,x-0.5*a};
   Double_t yokvir[5] = {y-0.07*b, y+b+0.07*b, y+b+0.07*b, y-0.07*b,y-0.07*b};
   okvir = new TPolyLine(5,xokvir,yokvir);//outer frame
   okvir->SetFillColor(38);
   okvir->SetLineColor(1);
   okvir->SetLineWidth(1);
   okvir->Draw("f");
   okvir->Draw();


   Double_t xokvir2[5] = {x, x, x+a, x+a, a*0.0+x};
   Double_t yokvir2[5] = {y, y+b, y+b, b*0.0+y, b*0.0+y};
   okvir2 = new TPolyLine(5,xokvir2,yokvir2);//inner frame
   okvir2->SetFillColor(0);
   okvir2->SetLineColor(1);
   okvir2->SetLineWidth(1);
   okvir2->Draw("f");
   okvir2->Draw();

   double dif = 5*2*0.00424/sqrt(2.); //There is total 368 sense wires in each plane, spaced 4.24 mm apart
   double l0 = 2*0.00424*17.0/sqrt(2.);//16 grounded wires 
   

   // now we make U - plane (we fill chamber with wires from right lower corner (wire number zero is actually wire number 17,
   // there are 16 grounded wires in the corner))
   for (int i = 0; i<Num; i++)
   {

      if (l0+dif*i <= Length)
      {
         u_wires[i] = new TLine(x+a-cst->transHorizontalLtoCL(l0+dif*i), y, x+a, y+cst->transVerticalLtoCL(l0+dif*i));
         u_wires[i]->SetLineColor(kGray);
         u_wires[i]->Draw();  
      }
      else if (l0+dif*i > Length && l0+dif*i <= Hight)
      {
         u_wires[i] = new TLine(x, y+cst->transVerticalLtoCL(l0+dif*i-Length), x+a, y+cst->transVerticalLtoCL(l0+dif*i));
         u_wires[i]->SetLineColor(kGray);
         u_wires[i]->Draw();   
      }
      else
      {
	 u_wires[i] = new TLine(x, y+cst->transVerticalLtoCL(l0+dif*i-Length), x+a-cst->transHorizontalLtoCL(l0+dif*i-Hight), y+b);
         u_wires[i]->SetLineColor(kGray);
         u_wires[i]->Draw();   
	}
   }

   // now we make V - plane (we fill chamber with wires from left lower corner) 

     for (int i = 0; i<Num; i++)
     {

        if (l0+dif*i <= Length)
	{
	  v_wires[i] = new TLine(x+cst->transHorizontalLtoCL(l0+dif*i), y, x, y+cst->transVerticalLtoCL(l0+dif*i));
          v_wires[i]->SetLineColor(kGray);
          v_wires[i]->Draw();   
	}
	else if (l0+dif*i > Length && l0+dif*i <= Hight)
	{
	  v_wires[i] = new TLine(x+a, y+cst->transVerticalLtoCL(l0+dif*i-Length), x, y+cst->transVerticalLtoCL(l0+dif*i));
          v_wires[i]->SetLineColor(kGray);
          v_wires[i]->Draw();  	  
	}
	else
	{
	  v_wires[i] = new TLine(x+a, y+cst->transVerticalLtoCL(l0+dif*i-Length), x+cst->transHorizontalLtoCL(l0+dif*i-Hight), y+b);
          v_wires[i]->SetLineColor(kGray);
          v_wires[i]->Draw();   
	}
     }


   
   // sedaj naredimo se semaforcek

   u_circ = new TEllipse(x+1.6*a, y+(b+0.1*b)/2+0.02*b, 0.04*a, 0.005*b);
   u_circ->SetFillColor(kGray);
   u_circ->Draw();

   TLatex *u_title = new TLatex(x+1.7*a, y+(b+0.1*b)/2+0.02*b,"U");
   u_title->SetTextSize(0.02);
   u_title->Draw(); 

   v_circ = new TEllipse(x+1.6*a, y+(b+0.1*b)/2-0.02*b, 0.04*a, 0.005*b);
   v_circ->SetFillColor(kGray);
   v_circ->Draw();

   TLatex *v_title = new TLatex(x+1.7*a, y+(b+0.1*b)/2-0.02*b, "V");
   v_title->SetTextSize(0.02);
   v_title->Draw(); 
 

   title = new TLatex(x+(a+0.01*a)/6.0, y+b+0.1*b, ime);
   title->SetTextSize(0.025);
   title->Draw(); 

   for(int i = 0; i<MAX_TRACK_NUM; i++) track_circ[i] = new TEllipse(0,0,0);
  
   cout<<"VDCChamber is created!"<<endl;

}

VDCChamber::~VDCChamber()
{

}

void VDCChamber::uWireHit(int i)
{
  int kvocient = (int) i/5;
  if (kvocient<Num)
  {
#if DEBUG_LEVEL >= 3	
    cout<<"****uWireHit: "<<kvocient<<endl;
#endif
    u_wires[kvocient]->SetLineColor(kGreen);
    u_wires[kvocient]->SetLineWidth(3);
    u_circ->SetFillColor(kGreen);
  }
  else
  {
#if DEBUG_LEVEL >= 3	
    cout<<"No wire with this number"<<endl;
#endif
  }
}

void VDCChamber::vWireHit(int i)
{
  int kvocient = (int) i/5;
  if (kvocient<Num)
  {
#if DEBUG_LEVEL >= 3	
    cout<<"****vWireHit: "<<kvocient<<endl;
#endif
    v_wires[kvocient]->SetLineColor(kRed);
    v_wires[kvocient]->SetLineWidth(3);
    v_circ->SetFillColor(kRed);
  }
  else
  {
#if DEBUG_LEVEL >= 3	
    cout<<"No wire with this number"<<endl;
#endif
  }
}

void VDCChamber::clear()
{
  for (int i = 0; i<Num; i++)
  {
    u_wires[i]->SetLineColor(kGray);
    u_wires[i]->SetLineWidth(1);
    v_wires[i]->SetLineColor(kGray);
    v_wires[i]->SetLineWidth(1);
 
    u_circ->SetFillColor(kGray);
    v_circ->SetFillColor(kGray);
  }

  for (int i = 0; i<MAX_TRACK_NUM; i++)
  {
    track_circ[i]->SetX1(0.0);
    track_circ[i]->SetY1(0.0);
    track_circ[i]->SetR1(0.0);
    track_circ[i]->SetR2(0.0);
    track_circ[i]->SetFillColor(kWhite);
    track_circ[i]->Draw();
  }
}

void VDCChamber::Track(double x, double y, int i)
{
#if DEBUG_LEVEL >= 3	
	cout<<"HURA: TRACK: (x,y): "<<x<<", "<<y<<endl;
#endif

	// First we need to transform meters to pixels
	double CX =  cst->transXtoCX(-y);
   	double CY =  cst->transYtoCY(-x);	

	track_circ[i]->SetX1(CX);
	track_circ[i]->SetY1(CY);
	track_circ[i]->SetR1(0.008);
	track_circ[i]->SetR2(0.008);
	//track_circ[i]->SetLineColor(kOrange+8);
	track_circ[i]->SetLineColor(1+i);
	track_circ[i]->SetLineWidth(2);
	//track_circ[i]->SetFillColor(kYellow);
	//track_circ[i]->SetFillColor(kOrange+0-i);
     	track_circ[i]->Draw();
	
  
}

